@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 import abc
 import copy
+import dataclasses
 import re
 import string
 
@@ -11,14 +14,10 @@ from enum import Enum
 from typing import TYPE_CHECKING
 from typing import Any
 from typing import Collection
-from typing import Dict
 from typing import Iterable
 from typing import Iterator
-from typing import List
-from typing import Optional
 from typing import Sequence
 from typing import TypeVar
-from typing import Union
 from typing import cast
 from typing import overload
 
@@ -61,90 +60,70 @@ ItemT = TypeVar("ItemT", bound="Item")
 
 
 @overload
-def item(
-    value: bool, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "Bool":
+def item(value: bool, _parent: Item | None = ..., _sort_keys: bool = ...) -> Bool:
+    ...
+
+
+@overload
+def item(value: int, _parent: Item | None = ..., _sort_keys: bool = ...) -> Integer:
+    ...
+
+
+@overload
+def item(value: float, _parent: Item | None = ..., _sort_keys: bool = ...) -> Float:
+    ...
+
+
+@overload
+def item(value: str, _parent: Item | None = ..., _sort_keys: bool = ...) -> String:
     ...
 
 
 @overload
 def item(
-    value: int, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "Integer":
+    value: datetime, _parent: Item | None = ..., _sort_keys: bool = ...
+) -> DateTime:
+    ...
+
+
+@overload
+def item(value: date, _parent: Item | None = ..., _sort_keys: bool = ...) -> Date:
+    ...
+
+
+@overload
+def item(value: time, _parent: Item | None = ..., _sort_keys: bool = ...) -> Time:
     ...
 
 
 @overload
 def item(
-    value: float, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "Float":
+    value: Sequence[dict], _parent: Item | None = ..., _sort_keys: bool = ...
+) -> AoT:
     ...
 
 
 @overload
-def item(
-    value: str, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "String":
+def item(value: Sequence, _parent: Item | None = ..., _sort_keys: bool = ...) -> Array:
     ...
 
 
 @overload
-def item(
-    value: datetime, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "DateTime":
+def item(value: dict, _parent: Array = ..., _sort_keys: bool = ...) -> InlineTable:
     ...
 
 
 @overload
-def item(
-    value: date, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "Date":
+def item(value: dict, _parent: Item | None = ..., _sort_keys: bool = ...) -> Table:
     ...
 
 
 @overload
-def item(
-    value: time, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "Time":
+def item(value: ItemT, _parent: Item | None = ..., _sort_keys: bool = ...) -> ItemT:
     ...
 
 
-@overload
-def item(
-    value: Sequence[dict], _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "AoT":
-    ...
-
-
-@overload
-def item(
-    value: Sequence, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "Array":
-    ...
-
-
-@overload
-def item(value: dict, _parent: "Array" = ..., _sort_keys: bool = ...) -> "InlineTable":
-    ...
-
-
-@overload
-def item(
-    value: dict, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> "Table":
-    ...
-
-
-@overload
-def item(
-    value: ItemT, _parent: Optional["Item"] = ..., _sort_keys: bool = ...
-) -> ItemT:
-    ...
-
-
-def item(
-    value: Any, _parent: Optional["Item"] = None, _sort_keys: bool = False
-) -> "Item":
+def item(value: Any, _parent: Item | None = None, _sort_keys: bool = False) -> Item:
     """Create a TOML item from a Python object.
 
     :Example:
@@ -179,10 +158,6 @@ def item(
             key=lambda i: (isinstance(i[1], dict), i[0] if _sort_keys else 1),
         ):
             val[k] = item(v, _parent=val, _sort_keys=_sort_keys)
-        only_child = val[next(iter(value))] if len(value) == 1 else None
-        if table_constructor is Table and isinstance(only_child, (AoT, Table)):
-            # The table becomes super table if the only child is a table or AoT.
-            val._is_super_table = True
 
         return val
     elif isinstance(value, (list, tuple)):
@@ -258,7 +233,7 @@ class StringType(Enum):
     MLL = "'''"
 
     @classmethod
-    def select(cls, literal=False, multiline=False) -> "StringType":
+    def select(cls, literal=False, multiline=False) -> StringType:
         return {
             (False, False): cls.SLB,
             (False, True): cls.MLB,
@@ -306,7 +281,7 @@ class StringType(Enum):
     def is_multiline(self) -> bool:
         return self in {StringType.MLB, StringType.MLL}
 
-    def toggle(self) -> "StringType":
+    def toggle(self) -> StringType:
         return {
             StringType.SLB: StringType.MLB,
             StringType.MLB: StringType.SLB,
@@ -329,32 +304,23 @@ class BoolType(Enum):
         return len(self.value)
 
 
+@dataclasses.dataclass
 class Trivia:
     """
     Trivia information (aka metadata).
     """
 
-    def __init__(
-        self,
-        indent: str = None,
-        comment_ws: str = None,
-        comment: str = None,
-        trail: str = None,
-    ) -> None:
-        # Whitespace before a value.
-        self.indent = indent or ""
-        # Whitespace after a value, but before a comment.
-        self.comment_ws = comment_ws or ""
-        # Comment, starting with # character, or empty string if no comment.
-        self.comment = comment or ""
-        # Trailing newline.
-        if trail is None:
-            trail = "\n"
+    # Whitespace before a value.
+    indent: str = ""
+    # Whitespace after a value, but before a comment.
+    comment_ws: str = ""
+    # Comment, starting with # character, or empty string if no comment.
+    comment: str = ""
+    # Trailing newline.
+    trail: str = "\n"
 
-        self.trail = trail
-
-    def copy(self) -> "Trivia":
-        return type(self)(self.indent, self.comment_ws, self.comment, self.trail)
+    def copy(self) -> Trivia:
+        return dataclasses.replace(self)
 
 
 class KeyType(Enum):
@@ -375,7 +341,7 @@ class Key(abc.ABC):
 
     sep: str
     _original: str
-    _keys: List["SingleKey"]
+    _keys: list[SingleKey]
     _dotted: bool
     key: str
 
@@ -391,10 +357,10 @@ class Key(abc.ABC):
         """If the key is followed by other keys"""
         return self._dotted
 
-    def __iter__(self) -> Iterator["SingleKey"]:
+    def __iter__(self) -> Iterator[SingleKey]:
         return iter(self._keys)
 
-    def concat(self, other: "Key") -> "DottedKey":
+    def concat(self, other: Key) -> DottedKey:
         """Concatenate keys into a dotted key"""
         keys = self._keys + other._keys
         return DottedKey(keys, sep=self.sep)
@@ -420,9 +386,9 @@ class SingleKey(Key):
     def __init__(
         self,
         k: str,
-        t: Optional[KeyType] = None,
-        sep: Optional[str] = None,
-        original: Optional[str] = None,
+        t: KeyType | None = None,
+        sep: str | None = None,
+        original: str | None = None,
     ) -> None:
         if t is None:
             if not k or any(
@@ -469,8 +435,8 @@ class DottedKey(Key):
     def __init__(
         self,
         keys: Iterable[Key],
-        sep: Optional[str] = None,
-        original: Optional[str] = None,
+        sep: str | None = None,
+        original: str | None = None,
     ) -> None:
         self._keys = list(keys)
         if original is None:
@@ -519,7 +485,7 @@ class Item:
 
     # Helpers
 
-    def comment(self, comment: str) -> "Item":
+    def comment(self, comment: str) -> Item:
         """Attach a comment to this item"""
         if not comment.strip().startswith("#"):
             comment = "# " + comment
@@ -529,7 +495,7 @@ class Item:
 
         return self
 
-    def indent(self, indent: int) -> "Item":
+    def indent(self, indent: int) -> Item:
         """Indent this item with given number of spaces"""
         if self._trivia.indent.startswith("\n"):
             self._trivia.indent = "\n" + " " * indent
@@ -623,7 +589,7 @@ class Integer(int, Item):
     An integer literal.
     """
 
-    def __new__(cls, value: int, trivia: Trivia, raw: str) -> "Integer":
+    def __new__(cls, value: int, trivia: Trivia, raw: str) -> Integer:
         return super().__new__(cls, value)
 
     def __init__(self, _: int, trivia: Trivia, raw: str) -> None:
@@ -651,28 +617,28 @@ class Integer(int, Item):
         return self._raw
 
     def __add__(self, other):
-        return self._new(int(self._raw) + other)
+        result = super().__add__(other)
+        if result is NotImplemented:
+            return result
+        return self._new(result)
 
     def __radd__(self, other):
         result = super().__radd__(other)
-
-        if isinstance(other, Integer):
-            return self._new(result)
-
-        return result
+        if result is NotImplemented:
+            return result
+        return self._new(result)
 
     def __sub__(self, other):
         result = super().__sub__(other)
-
+        if result is NotImplemented:
+            return result
         return self._new(result)
 
     def __rsub__(self, other):
         result = super().__rsub__(other)
-
-        if isinstance(other, Integer):
-            return self._new(result)
-
-        return result
+        if result is NotImplemented:
+            return result
+        return self._new(result)
 
     def _new(self, result):
         raw = str(result)
@@ -817,7 +783,7 @@ class DateTime(Item, datetime):
         minute: int,
         second: int,
         microsecond: int,
-        tzinfo: Optional[tzinfo],
+        tzinfo: tzinfo | None,
         *_: Any,
         **kwargs: Any,
     ) -> datetime:
@@ -843,9 +809,9 @@ class DateTime(Item, datetime):
         minute: int,
         second: int,
         microsecond: int,
-        tzinfo: Optional[tzinfo],
-        trivia: Optional[Trivia] = None,
-        raw: Optional[str] = None,
+        tzinfo: tzinfo | None,
+        trivia: Trivia | None = None,
+        raw: str | None = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(trivia or Trivia())
@@ -924,7 +890,7 @@ class DateTime(Item, datetime):
             return result
         return self._new(result)
 
-    def _new(self, result) -> "DateTime":
+    def _new(self, result) -> DateTime:
         raw = result.isoformat()
 
         return DateTime(
@@ -1027,7 +993,7 @@ class Time(Item, time):
         minute: int,
         second: int,
         microsecond: int,
-        tzinfo: Optional[tzinfo],
+        tzinfo: tzinfo | None,
         *_: Any,
     ) -> time:
         return time.__new__(cls, hour, minute, second, microsecond, tzinfo)
@@ -1038,7 +1004,7 @@ class Time(Item, time):
         minute: int,
         second: int,
         microsecond: int,
-        tzinfo: Optional[tzinfo],
+        tzinfo: tzinfo | None,
         trivia: Trivia,
         raw: str,
     ) -> None:
@@ -1094,10 +1060,10 @@ class _ArrayItemGroup:
 
     def __init__(
         self,
-        value: Optional[Item] = None,
-        indent: Optional[Whitespace] = None,
-        comma: Optional[Whitespace] = None,
-        comment: Optional[Comment] = None,
+        value: Item | None = None,
+        indent: Whitespace | None = None,
+        comma: Whitespace | None = None,
+        comment: Comment | None = None,
     ) -> None:
         self.value = value
         self.indent = indent
@@ -1129,19 +1095,19 @@ class Array(Item, _CustomList):
     """
 
     def __init__(
-        self, value: List[Item], trivia: Trivia, multiline: bool = False
+        self, value: list[Item], trivia: Trivia, multiline: bool = False
     ) -> None:
         super().__init__(trivia)
         list.__init__(
             self,
-            [v.value for v in value if not isinstance(v, (Whitespace, Comment, Null))],
+            [v for v in value if not isinstance(v, (Whitespace, Comment, Null))],
         )
-        self._index_map: Dict[int, int] = {}
+        self._index_map: dict[int, int] = {}
         self._value = self._group_values(value)
         self._multiline = multiline
         self._reindex()
 
-    def _group_values(self, value: List[Item]) -> List[_ArrayItemGroup]:
+    def _group_values(self, value: list[Item]) -> list[_ArrayItemGroup]:
         """Group the values into (indent, value, comma, comment) tuples"""
         groups = []
         this_group = _ArrayItemGroup()
@@ -1167,10 +1133,10 @@ class Array(Item, _CustomList):
         groups.append(this_group)
         return [group for group in groups if group]
 
-    def unwrap(self) -> List[Any]:
+    def unwrap(self) -> list[Any]:
         unwrapped = []
         for v in self:
-            if isinstance(v, Item):
+            if hasattr(v, "unwrap"):
                 unwrapped.append(v.unwrap())
             else:
                 unwrapped.append(v)
@@ -1188,7 +1154,7 @@ class Array(Item, _CustomList):
         for v in self._value:
             yield from v
 
-    def multiline(self, multiline: bool) -> "Array":
+    def multiline(self, multiline: bool) -> Array:
         """Change the array to display in multiline or not.
 
         :Example:
@@ -1239,7 +1205,7 @@ class Array(Item, _CustomList):
         self,
         *items: Any,
         indent: str = "    ",
-        comment: Optional[str] = None,
+        comment: str | None = None,
         add_comma: bool = True,
         newline: bool = True,
     ) -> None:
@@ -1259,7 +1225,7 @@ class Array(Item, _CustomList):
             4, 5, 6,
         ]
         """
-        new_values: List[Item] = []
+        new_values: list[Item] = []
         first_indent = f"\n{indent}" if newline else indent
         if first_indent:
             new_values.append(Whitespace(first_indent))
@@ -1320,12 +1286,15 @@ class Array(Item, _CustomList):
     def __len__(self) -> int:
         return list.__len__(self)
 
-    def __getitem__(self, key: Union[int, slice]) -> Any:
-        return list.__getitem__(self, key)
+    def __getitem__(self, key: int | slice) -> Any:
+        rv = cast(Item, list.__getitem__(self, key))
+        if rv.is_boolean():
+            return bool(rv)
+        return rv
 
-    def __setitem__(self, key: Union[int, slice], value: Any) -> Any:
+    def __setitem__(self, key: int | slice, value: Any) -> Any:
         it = item(value, _parent=self)
-        list.__setitem__(self, key, it.value)
+        list.__setitem__(self, key, it)
         if isinstance(key, slice):
             raise ValueError("slice assignment is not supported")
         if key < 0:
@@ -1336,7 +1305,7 @@ class Array(Item, _CustomList):
         it = item(value, _parent=self)
         length = len(self)
         if not isinstance(it, (Comment, Whitespace)):
-            list.insert(self, pos, it.value)
+            list.insert(self, pos, it)
         if pos < 0:
             pos += length
             if pos < 0:
@@ -1359,8 +1328,8 @@ class Array(Item, _CustomList):
                     and "\n" in self._value[idx].indent.s
                 ):
                     default_indent = "\n    "
-        indent: Optional[Item] = None
-        comma: Optional[Item] = Whitespace(",") if pos < length else None
+        indent: Item | None = None
+        comma: Item | None = Whitespace(",") if pos < length else None
         if idx < len(self._value) and not self._value[idx].is_whitespace():
             # Prefer to copy the indentation from the item after
             indent = self._value[idx].indent
@@ -1382,7 +1351,7 @@ class Array(Item, _CustomList):
         self._value.insert(idx, new_item)
         self._reindex()
 
-    def __delitem__(self, key: Union[int, slice]):
+    def __delitem__(self, key: int | slice):
         length = len(self)
         list.__delitem__(self, key)
 
@@ -1415,9 +1384,6 @@ class Array(Item, _CustomList):
 
         self._reindex()
 
-    def __str__(self):
-        return str([v.value.value for v in self._iter_items() if v.value is not None])
-
     def _getstate(self, protocol=3):
         return list(self._iter_items()), self._trivia, self._multiline
 
@@ -1428,7 +1394,7 @@ AT = TypeVar("AT", bound="AbstractTable")
 class AbstractTable(Item, _CustomDict):
     """Common behaviour of both :class:`Table` and :class:`InlineTable`"""
 
-    def __init__(self, value: "container.Container", trivia: Trivia):
+    def __init__(self, value: container.Container, trivia: Trivia):
         Item.__init__(self, trivia)
 
         self._value = value
@@ -1437,38 +1403,38 @@ class AbstractTable(Item, _CustomDict):
             if k is not None:
                 dict.__setitem__(self, k.key, v)
 
-    def unwrap(self) -> Dict[str, Any]:
+    def unwrap(self) -> dict[str, Any]:
         unwrapped = {}
         for k, v in self.items():
             if isinstance(k, Key):
                 k = k.key
-            if isinstance(v, Item):
+            if hasattr(v, "unwrap"):
                 v = v.unwrap()
             unwrapped[k] = v
 
         return unwrapped
 
     @property
-    def value(self) -> "container.Container":
+    def value(self) -> container.Container:
         return self._value
 
     @overload
-    def append(self: AT, key: None, value: Union[Comment, Whitespace]) -> AT:
+    def append(self: AT, key: None, value: Comment | Whitespace) -> AT:
         ...
 
     @overload
-    def append(self: AT, key: Union[Key, str], value: Any) -> AT:
+    def append(self: AT, key: Key | str, value: Any) -> AT:
         ...
 
     def append(self, key, value):
         raise NotImplementedError
 
     @overload
-    def add(self: AT, value: Union[Comment, Whitespace]) -> AT:
+    def add(self: AT, value: Comment | Whitespace) -> AT:
         ...
 
     @overload
-    def add(self: AT, key: Union[Key, str], value: Any) -> AT:
+    def add(self: AT, key: Key | str, value: Any) -> AT:
         ...
 
     def add(self, key, value=None):
@@ -1481,7 +1447,7 @@ class AbstractTable(Item, _CustomDict):
 
         return self.append(key, value)
 
-    def remove(self: AT, key: Union[Key, str]) -> AT:
+    def remove(self: AT, key: Key | str) -> AT:
         self._value.remove(key)
 
         if isinstance(key, Key):
@@ -1492,7 +1458,7 @@ class AbstractTable(Item, _CustomDict):
 
         return self
 
-    def setdefault(self, key: Union[Key, str], default: Any) -> Any:
+    def setdefault(self, key: Key | str, default: Any) -> Any:
         super().setdefault(key, default)
         return self[key]
 
@@ -1511,13 +1477,13 @@ class AbstractTable(Item, _CustomDict):
     def __len__(self) -> int:
         return len(self._value)
 
-    def __delitem__(self, key: Union[Key, str]) -> None:
+    def __delitem__(self, key: Key | str) -> None:
         self.remove(key)
 
-    def __getitem__(self, key: Union[Key, str]) -> Item:
+    def __getitem__(self, key: Key | str) -> Item:
         return cast(Item, self._value[key])
 
-    def __setitem__(self, key: Union[Key, str], value: Any) -> None:
+    def __setitem__(self, key: Key | str, value: Any) -> None:
         if not isinstance(value, Item):
             value = item(value, _parent=self)
 
@@ -1550,12 +1516,12 @@ class Table(AbstractTable):
 
     def __init__(
         self,
-        value: "container.Container",
+        value: container.Container,
         trivia: Trivia,
         is_aot_element: bool,
-        is_super_table: bool = False,
-        name: Optional[str] = None,
-        display_name: Optional[str] = None,
+        is_super_table: bool | None = None,
+        name: str | None = None,
+        display_name: str | None = None,
     ) -> None:
         super().__init__(value, trivia)
 
@@ -1568,7 +1534,7 @@ class Table(AbstractTable):
     def discriminant(self) -> int:
         return 9
 
-    def __copy__(self) -> "Table":
+    def __copy__(self) -> Table:
         return type(self)(
             self._value.copy(),
             self._trivia.copy(),
@@ -1578,7 +1544,7 @@ class Table(AbstractTable):
             self.display_name,
         )
 
-    def append(self, key, _item):
+    def append(self, key: Key | str | None, _item: Any) -> Table:
         """
         Appends a (key, item) to the table.
         """
@@ -1609,7 +1575,7 @@ class Table(AbstractTable):
 
         return self
 
-    def raw_append(self, key: Union[Key, str], _item: Any) -> "Table":
+    def raw_append(self, key: Key | str | None, _item: Any) -> Table:
         """Similar to :meth:`append` but does not copy indentation."""
         if not isinstance(_item, Item):
             _item = item(_item)
@@ -1632,14 +1598,20 @@ class Table(AbstractTable):
     def is_super_table(self) -> bool:
         """A super table is the intermediate parent of a nested table as in [a.b.c].
         If true, it won't appear in the TOML representation."""
-        return self._is_super_table
+        if self._is_super_table is not None:
+            return self._is_super_table
+        # If the table has only one child and that child is a table, then it is a super table.
+        if len(self) != 1:
+            return False
+        only_child = next(iter(self.values()))
+        return isinstance(only_child, (Table, AoT))
 
     def as_string(self) -> str:
         return self._value.as_string()
 
     # Helpers
 
-    def indent(self, indent: int) -> "Table":
+    def indent(self, indent: int) -> Table:
         """Indent the table with given number of spaces."""
         super().indent(indent)
 
@@ -1679,7 +1651,7 @@ class InlineTable(AbstractTable):
     """
 
     def __init__(
-        self, value: "container.Container", trivia: Trivia, new: bool = False
+        self, value: container.Container, trivia: Trivia, new: bool = False
     ) -> None:
         super().__init__(value, trivia)
 
@@ -1689,7 +1661,7 @@ class InlineTable(AbstractTable):
     def discriminant(self) -> int:
         return 10
 
-    def append(self, key, _item):
+    def append(self, key: Key | str | None, _item: Any) -> InlineTable:
         """
         Appends a (key, item) to the table.
         """
@@ -1714,6 +1686,14 @@ class InlineTable(AbstractTable):
 
     def as_string(self) -> str:
         buf = "{"
+        last_item_idx = next(
+            (
+                i
+                for i in range(len(self._value.body) - 1, -1, -1)
+                if self._value.body[i][0] is not None
+            ),
+            None,
+        )
         for i, (k, v) in enumerate(self._value.body):
             if k is None:
                 if i == len(self._value.body) - 1:
@@ -1736,7 +1716,7 @@ class InlineTable(AbstractTable):
                 f"{v_trivia_trail}"
             )
 
-            if i != len(self._value.body) - 1:
+            if last_item_idx is not None and i < last_item_idx:
                 buf += ","
                 if self._new:
                     buf += " "
@@ -1745,12 +1725,12 @@ class InlineTable(AbstractTable):
 
         return buf
 
-    def __setitem__(self, key: Union[Key, str], value: Any) -> None:
+    def __setitem__(self, key: Key | str, value: Any) -> None:
         if hasattr(value, "trivia") and value.trivia.comment:
             value.trivia.comment = ""
         super().__setitem__(key, value)
 
-    def __copy__(self) -> "InlineTable":
+    def __copy__(self) -> InlineTable:
         return type(self)(self._value.copy(), self._trivia.copy(), self._new)
 
     def _getstate(self, protocol: int = 3) -> tuple:
@@ -1793,14 +1773,14 @@ class String(str, Item):
 
         return self._new(result, original)
 
-    def _new(self, result: str, original: str) -> "String":
+    def _new(self, result: str, original: str) -> String:
         return String(self._t, result, original, self._trivia)
 
     def _getstate(self, protocol=3):
         return self._t, str(self), self._original, self._trivia
 
     @classmethod
-    def from_raw(cls, value: str, type_=StringType.SLB, escape=True) -> "String":
+    def from_raw(cls, value: str, type_=StringType.SLB, escape=True) -> String:
         value = decode(value)
 
         invalid = type_.invalid_sequences
@@ -1819,10 +1799,10 @@ class AoT(Item, _CustomList):
     """
 
     def __init__(
-        self, body: List[Table], name: Optional[str] = None, parsed: bool = False
+        self, body: list[Table], name: str | None = None, parsed: bool = False
     ) -> None:
         self.name = name
-        self._body: List[Table] = []
+        self._body: list[Table] = []
         self._parsed = parsed
 
         super().__init__(Trivia(trail=""))
@@ -1830,17 +1810,17 @@ class AoT(Item, _CustomList):
         for table in body:
             self.append(table)
 
-    def unwrap(self) -> List[Dict[str, Any]]:
+    def unwrap(self) -> list[dict[str, Any]]:
         unwrapped = []
         for t in self._body:
-            if isinstance(t, Item):
+            if hasattr(t, "unwrap"):
                 unwrapped.append(t.unwrap())
             else:
                 unwrapped.append(t)
         return unwrapped
 
     @property
-    def body(self) -> List[Table]:
+    def body(self) -> list[Table]:
         return self._body
 
     @property
@@ -1848,14 +1828,14 @@ class AoT(Item, _CustomList):
         return 12
 
     @property
-    def value(self) -> List[Dict[Any, Any]]:
+    def value(self) -> list[dict[Any, Any]]:
         return [v.value for v in self._body]
 
     def __len__(self) -> int:
         return len(self._body)
 
     @overload
-    def __getitem__(self, key: slice) -> List[Table]:
+    def __getitem__(self, key: slice) -> list[Table]:
         ...
 
     @overload
@@ -1865,10 +1845,10 @@ class AoT(Item, _CustomList):
     def __getitem__(self, key):
         return self._body[key]
 
-    def __setitem__(self, key: Union[slice, int], value: Any) -> None:
+    def __setitem__(self, key: slice | int, value: Any) -> None:
         raise NotImplementedError
 
-    def __delitem__(self, key: Union[slice, int]) -> None:
+    def __delitem__(self, key: slice | int) -> None:
         del self._body[key]
         list.__delitem__(self, key)
 
